Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(135)

Unified Diff: components/offline_pages/background/offliner.h

Issue 2149773002: PrerenderingOffliner will abort background load if it sees chrome transitioning to foreground on lo… (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Revise some comments wrt app listener setting/clearing Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/background/offliner.h
diff --git a/components/offline_pages/background/offliner.h b/components/offline_pages/background/offliner.h
index 0873186e75ef859131cbb4ab5c769030478d8564..8bc6468af55a0f51565c935886665af2bb3cb7a0 100644
--- a/components/offline_pages/background/offliner.h
+++ b/components/offline_pages/background/offliner.h
@@ -19,15 +19,22 @@ class Offliner {
// WARNING: You must update histograms.xml to match any changes made to
// this enum (ie, OfflinePagesBackgroundOfflinerRequestStatus histogram enum).
enum RequestStatus {
- UNKNOWN = 0, // No status determined/reported yet. Interim status, not sent
- // in callback.
- LOADED = 1, // Page loaded but not (yet) saved. Interim status, not sent in
- // callback.
- SAVED = 2, // Offline page snapshot saved.
- REQUEST_COORDINATOR_CANCELED = 3, // RequestCoordinator canceled request.
- PRERENDERING_CANCELED = 4, // Prerendering was canceled.
- PRERENDERING_FAILED = 5, // Prerendering failed to load page.
- SAVE_FAILED = 6, // Failed to save loaded page.
+ // No status determined/reported yet. Interim status, not sent in callback.
+ UNKNOWN = 0,
+ // Page loaded but not (yet) saved. Interim status, not sent in callback.
+ LOADED = 1,
+ // Offline page snapshot saved.
+ SAVED = 2,
+ // RequestCoordinator canceled request.
+ REQUEST_COORDINATOR_CANCELED = 3,
+ // Prerendering was canceled.
+ PRERENDERING_CANCELED = 4,
+ // Prerendering failed to load page.
+ PRERENDERING_FAILED = 5,
+ // Failed to save loaded page.
+ SAVE_FAILED = 6,
+ // Foreground transition canceled request.
+ FOREGROUND_CANCELED = 7,
// NOTE: insert new values above this line and update histogram enum too.
STATUS_COUNT
};
« no previous file with comments | « chrome/browser/android/offline_pages/prerendering_offliner_unittest.cc ('k') | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698